@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: resourcet
-version: 1.1.7.3
-id: resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
-key: resou_18RGQAU2akxEhnLKgc9Jq7
+version: 1.1.7.4
+id: resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
+key: resou_9iU2Xt7jNXX75MZ6y8sVHT
 license: BSD3
 maintainer: michael@snoyman.com
 homepage: http://github.com/snoyberg/conduit
@@ -17,10 +17,10 @@ exposed-modules:
     Control.Monad.Trans.Resource Control.Monad.Trans.Resource.Internal
     Data.Acquire Data.Acquire.Internal
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/resourcet-1.1.7.3
-library-dirs: /usr/lib/ghc-7.10.3/site-local/resourcet-1.1.7.3
-data-dir: /usr/share/arm-linux-ghc-7.10.3/resourcet-1.1.7.3
-hs-libraries: HSresourcet-1.1.7.3-18RGQAU2akxEhnLKgc9Jq7
+import-dirs: /usr/lib/ghc-7.10.3/site-local/resourcet-1.1.7.4
+library-dirs: /usr/lib/ghc-7.10.3/site-local/resourcet-1.1.7.4
+data-dir: /usr/share/arm-linux-ghc-7.10.3/resourcet-1.1.7.4
+hs-libraries: HSresourcet-1.1.7.4-9iU2Xt7jNXX75MZ6y8sVHT
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
